=======
Credits
=======

Development Team
----------------

* Jay Laura <jlaura@usgs.gov>
* Kristin Berry <kberry@usgs.gov>
* Jeannie Backer <jwbacker@usgs.gov>
* Dyer Lytle <dmlytle@usgs.gov>
* Kelvin Rodriguez <krodriguez@usgs.gov>
* Adam Paquette <acpaquette@usgs.gov>

Contributors
------------

`Ross Beyer <https://github.com/rbeyer>`_

